<?php
/**
* class WPSupersized
*
* Contains the functions for the plugin
* WP Supersized that
* adds Supersized 3.2.5 to WordPress 
*
*/

if ( !class_exists('WPSupersized') ):
class WPSupersized
{
	const plugin_name = 'WP Supersized';
        const plugin_version = '1.3';
	const min_php_version = '5.2';
	const min_wordpress_version = '3.1'; 
	const supersized_theme_name = 'shutter'; // should eventually be replaced by an option
	const supersized_version = '3.2.5';
	const supersized_core_version = '3.2.1';
	const supersized_flickr_version = '1.1.2';
        const supersized_jquery_easing_version = '1.3';


   /**
   * 
   * initialize()
   * This is the initialisation of the plugin
   * The required scripts and css files are registered here for later use
   */
     public static function initialize() {
		WPSupersized_Test::min_php_version(self::min_php_version, self::plugin_name);
		WPSupersized_Test::min_wordpress_version(self::min_wordpress_version, self::plugin_name);
                self::load_translation_file();
		wp_register_style('supersized', content_url().'/plugins/wp-supersized/css/supersized.css');
		wp_register_style('supersized_core', content_url().'/plugins/wp-supersized/css/supersized.core.css');
                wp_register_style('supersized_flickr', content_url().'/plugins/wp-supersized/css/supersized.flickr.css'); // for the flickr version 1.1.2, old css still needed
		wp_register_style('supersized_theme_css', content_url().'/plugins/wp-supersized/theme/supersized.'.self::supersized_theme_name.'.css');
		wp_register_script('WPSupersized_standard', content_url().'/plugins/wp-supersized/js/supersized.'.self::supersized_version.'.min.js',array('jquery'),self::supersized_version);
		wp_register_script('WPSupersized_core', content_url().'/plugins/wp-supersized/js/supersized.core.'.self::supersized_core_version.'.min.js',array('jquery'),self::supersized_core_version);
		wp_register_script('WPSupersized_flickr', content_url().'/plugins/wp-supersized/js/supersized.flickr.'.self::supersized_flickr_version.'.js',array('jquery'),self::supersized_flickr_version);
		wp_register_script('WPSupersized_theme_js', content_url().'/plugins/wp-supersized/theme/supersized.'.self::supersized_theme_name.'.min.js',array('jquery'));
		wp_register_script('jquery_easing', content_url().'/plugins/wp-supersized/js/jquery.easing.min.js',array('jquery'),self::supersized_jquery_easing_version);
}
   
/**
* Controller that generates admin page
*/


public static function generate_admin_page()
{
include('admin_page.php');
}

/**
* Adds a menu item inside the WordPress admin
*/

public static function add_menu_item()
{
add_options_page(
'WP Supersized Configuration', // page title
'WP Supersized', // menu title
'manage_options', // permissions
'wp-supersized', // page-name (used in the URL)
'WPSupersized::generate_admin_page' // clicking callback function
);
}

    /**
   *  _is_not_admin_page
   *
   * Check for WP admin area.
   * @return boolean   Simple true/false as to whether the current page is admin.
   */
   private static function _is_not_admin_page() {
      if (is_admin()) {
         return false;
      } else {
         return true;
      }
   }
   
    /**
   *  is_chosen_page
   *
   * Check for chosen page for display
   * @return boolean   Simple true/false as to whether the current page is chosen or not.
   */
   public static function is_chosen_page() {
	$where = get_option('wp-supersized_options');
        
        if($where['show_on_page']['everywhere'] == true)
            return true;
        
        if($where['show_in_page_id']['0'] !== '')
        {
            foreach ($where['show_in_page_id'] as $pageindex => $pageid)
            {
                if (is_page($pageid))
                    return true;                    
            }
        }
        
        if($where['show_in_template'])
        {
        $condition= false;
        foreach ($where['show_in_template'] as $i => $template_is_set)
        {
            if($template_is_set == true)
            { 
                $condition = true;}
        }

            if ($condition)
            {
            $templates_array = $where['templates_list'];
            reset($where['show_in_template']);
            foreach ($templates_array as $template_name => $template_filename)
            {
                if (is_page_template($template_filename) && $where['show_in_template'][$template_name])
                {
                return true;     }               
            }
            }
        }
        
        global $wp_query;
	$postid = $wp_query->post->ID;
	$custom_field_exists = get_post_meta($postid, 'SupersizedDir', true); // gets custom field outside of the loop
        if($where['show_on_page']['only_custom'] && $custom_field_exists && (is_single() || is_page())) // show only on post/page where a custom dir exists
            return true;

        if($where['show_in_post_id'][0] !== '')
        {
            foreach ($where['show_in_post_id'] as $postindex => $postid)
            {
                if (is_single($postid))
                    return true;                    
            }
        }
        
        if($where['show_in_category_id'][0] !== '')
        {
                if ((in_category($where['show_in_category_id']) || self::post_is_in_descendant_category($where['show_in_category_id'])) && is_single()) // checks for category or subcategory ID
                    return true;                    
        }

        if($where['show_in_tag_id'][0] !== '')
        {
                if (has_tag($where['show_in_tag_id']) && is_single())
                    return true;                    
        }

       	return(($where['show_on_page']['tag_archive'] && is_tag()) || ($where['show_on_page']['category_archive'] && is_category()) || ($where['show_on_page']['sticky_post'] && is_sticky()) || ($where['show_on_page']['allposts'] && is_single()) || ($where['show_on_page']['allpages'] && is_page()) || ($where['show_on_page']['homepage'] && is_home()) || ($where['show_on_page']['front_only'] && is_front_page()) || ($where['show_on_page']['404_page'] && is_404()) || ($where['show_on_page']['search_results'] && is_search()) || ($where['show_on_page']['date_archive'] && is_date()) || ($where['show_on_page']['any_archive'] && is_archive())) ; 

        
}

	/**
	*
	* _Supersized_scripts
	*
	*/
	public static function _Supersized_scripts() {
		  if (self::_is_not_admin_page() && self::is_chosen_page()) // conditional scripts enqueing - registering done in initialize
	{
        $options = get_option('wp-supersized_options');
  
			switch($options['slideshow'])
			{
			case 1:
                                wp_enqueue_script('jquery');
                                wp_enqueue_script('jquery_easing');
				wp_enqueue_script('WPSupersized_standard');
                                wp_enqueue_script('WPSupersized_theme_js');
				break;
			case 2:
				wp_enqueue_script('jquery');
				wp_enqueue_script('WPSupersized_core');
				break;
			case 3:
				wp_enqueue_script('jquery');
				wp_enqueue_script('WPSupersized_flickr');
				break;
			
			} 
	}
}
	/**
	*
	* _Supersized_styles
	*
	*/
	public static function _Supersized_styles() {
		  if (self::_is_not_admin_page() && self::is_chosen_page()) // conditional css enqueing - registering done in initialize
	{
        $options = get_option('wp-supersized_options');
 
			switch($options['slideshow'])
			{
			case 1:
				wp_enqueue_style('supersized');
                                wp_enqueue_style('supersized_theme_css');
				break;
			case 2:
				wp_enqueue_style('supersized_core');  

				break;
			case 3:
				wp_enqueue_style('supersized_flickr'); //uses the old css for flickr

				break;
			
			} 
	}
}
   /**
   *
   * This is the Supersized Header part.
   * Outputs all scripts and options.
   */
  public static function addHeaderCode() {  

	if (self::_is_not_admin_page() && self::is_chosen_page())
        {
 	$options = get_option('wp-supersized_options');
	foreach($options as $key => $value)
	{
	switch($value)
		{
		case 'true': // replaces true by 1
			$options[$key] = '1';
			break;
		case '': // and false by 0
			$options[$key] = '0';
			break;
		}
	}
        ?>
	<!--
	Supersized <?php echo self::supersized_version; ?> - Fullscreen Background jQuery Plugin
	www.buildinternet.com/project/supersized
	
	By Sam Dunn / One Mighty Roar (www.onemightyroar.com)
	Released under MIT License / GPL License
 
        Adapted for Wordpress (<?php echo self::plugin_name.' '.self::plugin_version; ?>) by Benoit De Boeck / World in my Eyes (www.worldinmyeyes.be)
	-->
        
		<script type="text/javascript">  
			jQuery(document).ready(function($) {
				$.supersized({
				<?php
				if ($options['slideshow'] !== '2') // Some options not needed for Single image mode
				{
				?>
					slideshow               : <?php echo $options['slideshow']; ?>,
					autoplay		: <?php echo $options['autoplay']; ?>,
                                <?php
				}
                                ?>
					start_slide             : <?php echo $options['start_slide']; ?>,
                                <?php
                                if ($options['slideshow'] !== '2') // Some options not needed for Single image mode
                                {
				?>
					random			: <?php echo $options['random']; ?>,
					slide_interval          : <?php echo $options['slide_interval']; ?>,
					transition              : <?php echo $options['transition']; ?>,
					transition_speed	: <?php echo $options['transition_speed']; ?>,
					new_window		: <?php echo $options['new_window']; ?>,
					pause_hover             : <?php echo $options['pause_hover']; ?>,
                                        stop_loop               : <?php echo $options['stop_loop']; ?>,
					keyboard_nav            : <?php echo $options['keyboard_nav']; ?>,
					performance		: <?php echo $options['performance']; ?>,
                                        
                                <?php
				}
				?>
					image_protect		: <?php echo $options['image_protect']; ?>,
					image_path		: '<?php echo content_url()?>/plugins/wp-supersized/<?php if($options['slideshow'] == '3') echo 'flickr_';?>img/',
					min_width		: <?php echo $options['min_width']; ?>,
					min_height		: <?php echo $options['min_height']; ?>,
					vertical_center         : <?php echo $options['vertical_center']; ?>,
					horizontal_center       : <?php echo $options['horizontal_center']; ?>,
                                        fit_always         	: <?php echo $options['fit_always']; ?>,
					fit_portrait         	: <?php echo $options['fit_portrait']; ?>,
					fit_landscape		: <?php echo $options['fit_landscape']; ?>,
				<?php
                                if ($options['slideshow'] !== '2') // Some options not needed for Single image mode
				{
                                ?>
					thumbnail_navigation    : <?php echo $options['thumbnail_navigation']; ?>,
                                        thumb_links             : <?php echo $options['thumb_links']; ?>,
					slide_counter           : <?php echo $options['slide_counter']; ?>,
					slide_captions          : <?php echo $options['slide_captions']; ?>,  
                                <?php
				}
                                if ($options['slideshow'] == '3') // Options for Flickr mode
				{
                                ?>      source                  : <?php echo $options['flickr_source']; ?>,
                                        set                     : '<?php echo $options['flickr_set']; ?>',
                                        user                    : '<?php echo $options['flickr_user']; ?>',
                                        group                   : '<?php echo $options['flickr_group']; ?>',
                                        tags                   : '<?php echo $options['flickr_tags']; ?>',
                                        total_slides            : <?php echo $options['flickr_total_slides']; ?>,
                                        image_size              : '<?php echo $options['flickr_size']; ?>',
                                        api_key                 : '<?php echo $options['flickr_api_key']; ?>'
				<?php
				}
                                if ($options['slideshow'] !== '3') // Options not needed for old Flickr mode
                                {
				?>
					slides                  :  [<?php self::slides_list(); //outputs the list of slides in the correct format
                                ?>],
                                        slide_links             : '<?php echo $options['slide_links']; ?>',
                                        progress_bar		: <?php echo $options['progress_bar']; ?>,						
					mouse_scrub		: <?php echo $options['mouse_scrub']; }?>												
				}); 
		    });
		</script>
            <?php

                                }
}		
   /**
   *
   * This is the Supersized Footer part.
   * Adds the Navigation.
   */
		  public static function addFooterCode() {
	if (self::_is_not_admin_page() && self::is_chosen_page()) // only on the right pages
        {
		  $options = get_option('wp-supersized_options');
                  
                        if ($options['navigation'] && $options['slideshow'] == '3') { // only for old flickr look
                        ?> 
                        	<!--Thumbnail Navigation-->
	<div id="prevthumb"></div> <div id="nextthumb"></div>
	
	<!--Control Bar-->
	<div id="controls-wrapper">
		<div id="controls">
			<?php
			if ($options['slide_counter'] == 'true') // Needed to get rid of the slide counter if switched off
			{
			?>
			<!--Slide counter-->
			<div id="slidecounter">
				<span class="slidenumber"></span>/<span class="totalslides"></span>
			</div>
			<?php
			}
			?>
						<!--Slide captions displayed here-->
			<div id="slidecaption"></div>
			<?php
			if ($options['navigation_controls'] == 'true') // If true, show navigation controls
			{
			?>
			
			<!--Navigation-->
			<div id="navigation">
                            <img id="prevslide" src="<?php echo content_url().'/plugins/wp-supersized/'; ?>flickr_img/back_dull.png"/><img id="pauseplay" src="<?php echo content_url().'/plugins/wp-supersized/'; ?>flickr_img/pause_dull.png"/><img id="nextslide" src="<?php echo content_url().'/plugins/wp-supersized/'; ?>flickr_img/forward_dull.png"/>
			</div>			
		</div>
	</div>
                        <?php 
                        }
                        } // end of the old flickr part
                        
			else {
                            if ($options['navigation'] && $options['slideshow'] !== '2') // to get rid of all navigation if switched off or when in Single image mode
                            {
                        ?>
                        <!--Thumbnail Navigation-->
                        <div id="prevthumb"></div>
                        <div id="nextthumb"></div>
                        <?php
                        }
                                if ($options['navigation_controls'] && $options['slideshow'] !== '2') // If true, show navigation arrows
                        {
                        ?>
			<!-- Arrow Navigation -->
			<a id="prevslide" class="load-item"></a>
                        <a id="nextslide" class="load-item"></a>
                        <?php
                        }
                        if ($options['navigation'] && $options['slideshow'] !== '2') // to get rid of all navigation if switched off or when in Single image mode
			{
                        ?>

                        <div id="thumb-tray" class="load-item">
                            <div id="thumb-back"></div>
                            <div id="thumb-forward"></div>
                        </div>
                        <?php
                        if ($options['progress_bar'])
                        {
                        ?>
                        <!--Time Bar-->
                        <div id="progress-back" class="load-item">
                            <div id="progress-bar"></div>
                        </div>
                        <?php
                        }
                        ?>
                        <!--Control Bar-->
                        <div id="controls-wrapper" class="load-item">
                        <div id="controls">
                        <a id="play-button"><img id="pauseplay" src="<?php echo get_bloginfo('wpurl'); ?>/wp-content/plugins/wp-supersized/img/pause.png"/></a>
                        
			<?php
                                if ($options['slide_counter']) // If true, show slide counter
			{
			?>
			<!--Slide counter-->
			<div id="slidecounter">
				<span class="slidenumber"></span>/<span class="totalslides"></span>
			</div>
			<?php
			}
                                if ($options['slide_captions']) // If true, show slide caption
                        {
                        ?>
			<!--Slide captions displayed here-->
			<div id="slidecaption"></div>
                        <?php
                        }
                                if ($options['thumb_tray']) // If true, show thumb tray button
			{
			?>
                        <!--Thumb Tray button-->
			<a id="tray-button"><img style="height:42px;" id="tray-arrow" src="<?php echo get_bloginfo('wpurl'); ?>/wp-content/plugins/wp-supersized/img/button-tray-up.png"/></a>
                        <?php
                        }
			?>
                        <!--Navigation-->
			<ul id="slide-list"></ul>
                       
			
		</div>
	</div>
	<?php
			}
                        }
        }
}

	 /**
	*
	* Reads and outputs the list of slides
	*
	*/
	
        public static function slides_list()
	{
	$options = get_option('wp-supersized_options');
        
        $full_dir = self::get_custom_dir($options['default_dir']);

        if ($full_dir) {
            $dir = './wp-content/'.$full_dir."/";
            $thumbs_dir = $dir."thumbs/";
            $dirArray = glob($dir."*.{jpg,JPG,png,PNG,gif,GIF,jpeg,JPEG}",GLOB_BRACE);
            asort($dirArray); //dirArray is sorted to make sure that it is in alphabetical order
        }
                
        else {
            $thumbsdirArray = $dirArray = $thumbs_dir = $dir = '';
        }
        
        if ($options['debugging_mode']) {
        echo "\n".'/*'."\n".'full_dir = '.$full_dir."\n".'dir = '.$dir."\n".'thumbs_dir = '.$thumbs_dir."\n".'dirArray = ';
        print_r($dirArray);
        echo "\n".'*/'."\n"; //debugging mode
        }
        
        if (file_exists($thumbs_dir) && !self::is_empty_dir($thumbs_dir)) {
            $thumbsdirArray = glob($thumbs_dir."*.{jpg,JPG,png,PNG,gif,GIF,jpeg,JPEG}",GLOB_BRACE);
            asort($thumbsdirArray); //thumbsdirArray is sorted to make sure that it is in alphabetical order
            foreach ($thumbsdirArray as $key => $path) {
                $shortthumbsdirArray[$key] = str_ireplace('./wp-content', '', $path); // removes the wp-content part of the path to allow the use of content_url()
            }
        }
        else $shortthumbsdirArray = $thumbsdirArray = $thumbs_dir = '';
        
        foreach ($dirArray as $key => $path) {
            $short_dirArray[$key] = str_ireplace('./wp-content', '', $path);
	}
        
        $indexCount = count($dirArray);
        if ($options['background_url'])
            $full_background_url = "http://".$options['background_url'];
        else $full_background_url = '';

         // loops through the array of files and print them all
				
			if ($options['slideshow'] == '1' | ($options['slideshow'] == '2' && $options['start_slide'] == '0'))
			{
			// First for the Slideshow mode or the Single image mode with random on
				if ($indexCount >= 2 && $dir) // only show the slides if there are at least 2 and there is a dir containing images
				{
					for($index=0; $index < $indexCount-1; $index++) {
						$iptc_caption = self::_show_iptc_caption($dirArray[$index]);
						$converted_caption = self::asciitothmlcode($iptc_caption);
                                                if ($thumbs_dir && file_exists($thumbs_dir))
                                                    $thumbnail_link = content_url().$shortthumbsdirArray[$index];
                                                else $thumbnail_link = '';
                                                echo "\n{image : '" . content_url().$short_dirArray[$index] . "', title : '".$converted_caption."', thumb : '".$thumbnail_link."', url : '" . $full_background_url . "'},";
						}
					
					$iptc_caption = self::_show_iptc_caption($dirArray[$index]);
					$converted_caption = self::asciitothmlcode($iptc_caption);
                                        if ($thumbs_dir && file_exists($thumbs_dir))
                                            $thumbnail_link = content_url().$shortthumbsdirArray[$index];
                                        else $thumbnail_link = '';
                                        echo "\n{image : '" . content_url().$short_dirArray[$index] . "', title : '" . $converted_caption ."', thumb : '".$thumbnail_link . "', url : '" . $full_background_url . "'}"; // The last line MUST be without comma
				}
				else // otherwise show the original Supersized examples
					echo "\n{image : 'http://buildinternet.s3.amazonaws.com/projects/supersized/3.1/slides/quietchaos-kitty.jpg', title : 'Quiet Chaos by Kitty Gallannaugh', url : 'http://www.nonsensesociety.com/2010/12/kitty-gallannaugh/'},\n{image : 'http://buildinternet.s3.amazonaws.com/projects/supersized/3.1/slides/wanderers-kitty.jpg', title : 'Wanderers by Kitty Gallannaugh', url : 'http://www.nonsensesociety.com/2010/12/kitty-gallannaugh/'}";
			}
			else
			// Then for the Single image mode
				{
				reset ($dirArray);
                                $indexCount = count($dirArray);
                                
					if ($indexCount >= 1 && $dir) // Shows the first image in the array if present and if there is dir containing images
					{
						$iptc_caption = self::_show_iptc_caption($dirArray['0']);
						$converted_caption = self::asciitothmlcode($iptc_caption);
                                                echo "\n{image : '" . content_url().$short_dirArray[0] . "', title : '', thumb : '', url : '" . $full_background_url . "'}";
					}
					else // or the original Supersized example if slides folder is empty
						echo "\n{image : 'http://buildinternet.s3.amazonaws.com/projects/supersized/3.1/slides/quietchaos-kitty.jpg', title : 'Quiet Chaos by Kitty Gallannaugh', url : 'http://www.nonsensesociety.com/2010/12/kitty-gallannaugh/'}";
				} 
				  
		}
	/**
	*
	* get_custom_dir ($default_dir)
	* checks if default dir and custom dir exist
	* and returns the correct dir for display
	*
	*/
	
	public static function get_custom_dir($default_dir) {
            
		global $wp_query;
		$postid = $wp_query->post->ID;
		$custom_dir = get_post_meta($postid, 'SupersizedDir', true); // gets custom field outside of the loop
                $full_custom_dir = "./wp-content/".$custom_dir;
                $full_default_dir = "./wp-content/".$default_dir;
                
                $options = get_option('wp-supersized_options');
                if ($options['debugging_mode']) {
                    echo "\n".'/*'."\n".'custom_dir = '.$custom_dir."\n".'full_custom_dir = '.$full_custom_dir."\n".'full_default_dir = '.$full_default_dir."\n".'content_url = '.content_url()."\n".' */'."\n"; //debugging mode
                }
                if ($default_dir && is_dir($full_default_dir) && (is_tag() || is_category() || is_archive() || is_date())) // to make sure that the Tag or category archive gets the right dir  
                        return $default_dir;
                if ($custom_dir && is_dir($full_custom_dir) && (is_single() || is_page())) // to make sure that the custom dir images only appear on single posts/pages and not in tag or category archives      
                        return $custom_dir;
		else
                    return $default_dir;
	}
        
         /**
         * 
         * is_empty_dir($dir)
         * Checks if a folder is empty
         * 
         */

         public static function is_empty_dir($dir)
        {
        if (($files = @scandir($dir)) && count($files) <= 2) {
            return true;
            }
        return false;
        }
        
        /**
	*
	* _show_iptc_caption($filename)
	* gets IPTC caption and returns it
	*
	*/

	public static function _show_iptc_caption($filename) {
         	$size = getimagesize($filename, $info);
			if(isset($info['APP13']))
				{
				   $iptc = iptcparse($info['APP13']);
        if (is_array($iptc)) { 
        $caption = $iptc['2#120'][0]; 
		}
            }
        return $caption;         }   
		
	 /**
	*
	* Installation - Sets the options defaults
        * Done only once at activation
	*
	*/
	public static function install () {
        $previous_options = get_option('wp-supersized_options');
        if ($previous_options['reset_options'] || !is_array($previous_options)) { // if reset or fresh install
	$newoptions['slideshow'] = '1';
	$newoptions['autoplay'] = 'true';
	$newoptions['start_slide'] = '1';
	$newoptions['random'] = '';
	$newoptions['slide_interval'] = '3000';
	$newoptions['transition'] = '1';
	$newoptions['transition_speed'] = '500';
	$newoptions['new_window'] = 'true';
	$newoptions['pause_hover'] = '';
	$newoptions['keyboard_nav'] = 'true';
	$newoptions['performance'] = '1';
	$newoptions['image_protect'] = '';
	$newoptions['min_width'] = '0';
	$newoptions['min_height'] = '0';
	$newoptions['vertical_center'] = 'true';
	$newoptions['horizontal_center'] = 'true';
	$newoptions['fit_portrait'] = 'true';
	$newoptions['fit_landscape'] = '';
	$newoptions['navigation'] = 'true';
        $newoptions['background_url'] = ''; // new option for version 1.2
	$newoptions['thumbnail_navigation'] = '';
	$newoptions['navigation_controls'] = 'true';
	$newoptions['slide_counter'] = 'true';
	$newoptions['slide_captions'] = 'true';
	$newoptions['flickr_source'] = '3';
	$newoptions['flickr_set'] = '';
	$newoptions['flickr_user'] = '';
	$newoptions['flickr_group'] = '';
        $newoptions['flickr_tags'] = ''; // new option for version 1.1.1
	$newoptions['flickr_total_slides'] = '100';
	$newoptions['flickr_size'] = 'z';
	$newoptions['flickr_api_key'] = '';
	$newoptions['show_on_page'] = array(
            'allposts' => '',
            'homepage' => '',
            'allpages' => '',
            'front_only' => '',
            'sticky_post' => '',
            '404_page' => '',
            'search_results' => '', // new option for version 1.2
            'category_archive' => '', // new option for version 1.1
            'tag_archive' => '', // new option for version 1.1
            'only_custom' => '', // new option for version 1.1
            'any_archive' => '', // new option for version 1.2
            'date_archive' => '', // new option for version 1.2
            'everywhere' => '' // new option for version 1.2
            );
        $newoptions['templates_list'] = get_page_templates();
        foreach ($newoptions['templates_list'] as $templateID => $templatefilename)
            {
              $newoptions['show_in_template'][$templateID] = '';                      
            }
	$newoptions['show_in_page_id'] = array('0' => '');
	$newoptions['show_in_post_id'] = array('0' => '');
        $newoptions['show_in_category_id'] = array('0' => ''); // new option for version 1.1
        $newoptions['show_in_tag_id'] = array('0' => ''); // new option for version 1.1
        $newoptions['stop_loop'] = ''; //new option for version 1.1
        $newoptions['fit_always'] = ''; //new option for version 1.1
        $newoptions['slide_links'] = 'blank'; //new option for version 1.1
        $newoptions['thumb_links'] = 'true'; //new option for version 1.1
        $newoptions['thumbnail_suffix'] = '-1'; //new option for version 1.1
        $newoptions['progress_bar'] = 'true'; //new option for version 1.1
        $newoptions['mouse_scrub'] = ''; //new option for version 1.1
        $newoptions['thumb_tray'] = 'true'; //new option for version 1.1
        $newoptions['default_dir'] = 'supersized-slides'; //new option for version 1.1
        $newoptions['debugging_mode'] = ''; //new option for version 1.3
        $newoptions['reset_options'] = ''; //new option for version 1.1
        
        }
        elseif (is_array($previous_options) && !array_key_exists('default_dir', $previous_options)) { // if options already set for previous version, sets defaults for new options only
            foreach ($previous_options as $option_key => $option_value) // keep the previous options
            {
                $newoptions[$option_key] = $previous_options[$option_key];
            }     
        
        $newoptions['show_on_page'] = array(
            'category_archive' => '', // new option for version 1.1
            'tag_archive' => '', // new option for version 1.1
            'only_custom' => '', // new option for version 1.1
            'search_results' => '', // new option for version 1.2
            'any_archive' => '', // new option for version 1.2
            'date_archive' => '', // new option for version 1.2
            'everywhere' => '' // new option for version 1.2
            );
        $newoptions['show_in_category_id'] = array('0' => ''); // new option for version 1.1
        $newoptions['show_in_tag_id'] = array('0' => ''); // new option for version 1.1
        $newoptions['stop_loop'] = ''; //new option for version 1.1
        $newoptions['fit_always'] = ''; //new option for version 1.1
        $newoptions['slide_links'] = 'blank'; //new option for version 1.1
        $newoptions['thumb_links'] = ''; //new option for version 1.1
        $newoptions['thumbnail_suffix'] = '-1'; //new option for version 1.1
        $newoptions['progress_bar'] = 'true'; //new option for version 1.1
        $newoptions['mouse_scrub'] = ''; //new option for version 1.1
        $newoptions['thumb_tray'] = 'true'; //new option for version 1.1
        $newoptions['default_dir'] = 'supersized-slides'; //new option for version 1.1
        $newoptions['debugging_mode'] = ''; //new option for version 1.3
        $newoptions['reset_options'] = ''; //new option for version 1.1
        
        $newoptions['flickr_tags'] = ''; // new option for version 1.1.1
        $newoptions['background_url'] = ''; // new option for version 1.2
        }
        elseif (is_array($previous_options) && !array_key_exists('flickr_tags', $previous_options)) {
                foreach ($previous_options as $option_key => $option_value) // keep the previous options
            {
                $newoptions[$option_key] = $previous_options[$option_key];
            }   
            $newoptions['flickr_tags'] = ''; // new option for version 1.1.1
            $newoptions['show_on_page']['search_results'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['everywhere'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['any_archive'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['date_archive'] = ''; // new option for version 1.2
            $newoptions['background_url'] = ''; // new option for version 1.2
            $newoptions['debugging_mode'] = ''; //new option for version 1.3
            
        }
        elseif (is_array($previous_options) && !array_key_exists('everywhere', $previous_options)) {
                foreach ($previous_options as $option_key => $option_value) // keep the previous options
            {
                $newoptions[$option_key] = $previous_options[$option_key];
            }   
            $newoptions['show_on_page']['everywhere'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['search_results'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['any_archive'] = ''; // new option for version 1.2
            $newoptions['show_on_page']['date_archive'] = ''; // new option for version 1.2
            $newoptions['background_url'] = ''; // new option for version 1.2
            $newoptions['debugging_mode'] = ''; //new option for version 1.3
            
        }
        
        elseif (is_array($previous_options) && !array_key_exists('debugging_mode', $previous_options)) {
                foreach ($previous_options as $option_key => $option_value) // keep the previous options
            {
                $newoptions[$option_key] = $previous_options[$option_key];
            }   
            $newoptions['debugging_mode'] = ''; //new option for version 1.3
            
        }
        
        else return; // do not modify the existing options

	update_option('wp-supersized_options', $newoptions); // Sets defaults for options
}
	//uninstall all options
	
        /**
         * 
         * Delete options when uninstalling the plugin
         * 
         */
        public static function uninstall () {
	delete_option('wp-supersized_options');
}

        /**
         * 
         * Adds the settings link for the plugin
         * 
         */

        public static function add_plugin_settings_link($links, $file)
        {
        $settings_link = sprintf('<a href="%s">%s</a>', admin_url( 'options-general.php?page=wp-supersized' ), 'Settings');
        array_unshift( $links, $settings_link );
        return $links;
        }
       
/*
*
* asciitohtmlcode ($string)
* Replaces special characters by their html equivalents
* Returns $string
*
*/

public static function asciitothmlcode($string) {

    $asciiarray[] = 39; $htmlarray[] = "&#39;";
    $asciiarray[] = 192; $htmlarray[] = "&#192;";
    $asciiarray[] = 193; $htmlarray[] = "&#193;";
    $asciiarray[] = 194; $htmlarray[] = "&#194;";
    $asciiarray[] = 195; $htmlarray[] = "&#195;";
    $asciiarray[] = 196; $htmlarray[] = "&#196;";
    $asciiarray[] = 197; $htmlarray[] = "&#197;";
    $asciiarray[] = 198; $htmlarray[] = "&#198;";
    $asciiarray[] = 199; $htmlarray[] = "&#199;";
    $asciiarray[] = 200; $htmlarray[] = "&#200;";
    $asciiarray[] = 201; $htmlarray[] = "&#201;";
    $asciiarray[] = 202; $htmlarray[] = "&#202;";
    $asciiarray[] = 203; $htmlarray[] = "&#203;";
    $asciiarray[] = 204; $htmlarray[] = "&#204;";
    $asciiarray[] = 205; $htmlarray[] = "&#205;";
    $asciiarray[] = 206; $htmlarray[] = "&#206;";
    $asciiarray[] = 207; $htmlarray[] = "&#207;";
    $asciiarray[] = 208; $htmlarray[] = "&#208;";
    $asciiarray[] = 209; $htmlarray[] = "&#209;";
    $asciiarray[] = 210; $htmlarray[] = "&#210;";
    $asciiarray[] = 211; $htmlarray[] = "&#211;";
    $asciiarray[] = 212; $htmlarray[] = "&#212;";
    $asciiarray[] = 213; $htmlarray[] = "&#213;";
    $asciiarray[] = 214; $htmlarray[] = "&#214;";
    $asciiarray[] = 215; $htmlarray[] = "&#215;";
    $asciiarray[] = 216; $htmlarray[] = "&#216;";
    $asciiarray[] = 217; $htmlarray[] = "&#217;";
    $asciiarray[] = 218; $htmlarray[] = "&#218;";
    $asciiarray[] = 219; $htmlarray[] = "&#219;";
    $asciiarray[] = 220; $htmlarray[] = "&#220;";
    $asciiarray[] = 221; $htmlarray[] = "&#221;";
    $asciiarray[] = 222; $htmlarray[] = "&#222;";
    $asciiarray[] = 223; $htmlarray[] = "&#223;";
    $asciiarray[] = 224; $htmlarray[] = "&#224;";
    $asciiarray[] = 225; $htmlarray[] = "&#225;";
    $asciiarray[] = 226; $htmlarray[] = "&#226;";
    $asciiarray[] = 227; $htmlarray[] = "&#227;";
    $asciiarray[] = 228; $htmlarray[] = "&#228;";
    $asciiarray[] = 229; $htmlarray[] = "&#229;";
    $asciiarray[] = 230; $htmlarray[] = "&#230;";
    $asciiarray[] = 231; $htmlarray[] = "&#231;";
    $asciiarray[] = 232; $htmlarray[] = "&#232;";
    $asciiarray[] = 233; $htmlarray[] = "&#233;";
    $asciiarray[] = 234; $htmlarray[] = "&#234;";
    $asciiarray[] = 235; $htmlarray[] = "&#235;";
    $asciiarray[] = 236; $htmlarray[] = "&#236;";
    $asciiarray[] = 237; $htmlarray[] = "&#237;";
    $asciiarray[] = 238; $htmlarray[] = "&#238;";
    $asciiarray[] = 239; $htmlarray[] = "&#239;";
    $asciiarray[] = 240; $htmlarray[] = "&#240;";
    $asciiarray[] = 241; $htmlarray[] = "&#241;";
    $asciiarray[] = 242; $htmlarray[] = "&#242;";
    $asciiarray[] = 243; $htmlarray[] = "&#243;";
    $asciiarray[] = 244; $htmlarray[] = "&#244;";
    $asciiarray[] = 245; $htmlarray[] = "&#245;";
    $asciiarray[] = 246; $htmlarray[] = "&#246;";
    $asciiarray[] = 247; $htmlarray[] = "&#247;";
    $asciiarray[] = 248; $htmlarray[] = "&#248;";
    $asciiarray[] = 249; $htmlarray[] = "&#249;";
    $asciiarray[] = 250; $htmlarray[] = "&#250;";
    $asciiarray[] = 251; $htmlarray[] = "&#251;";
    $asciiarray[] = 252; $htmlarray[] = "&#252;";
    $asciiarray[] = 253; $htmlarray[] = "&#253;";
    $asciiarray[] = 254; $htmlarray[] = "&#254;";
    $asciiarray[] = 255; $htmlarray[] = "&#255;";

    $i = 0;
    while ($i < sizeof ($asciiarray)){
        $string = str_replace(chr($asciiarray[$i]), $htmlarray[$i], $string);
        $i++;
    }
    return $string;

}

/*
 * 
 * load_translation_file()
 * Loads the translation files during initialization
 * 
 */
public static function load_translation_file()
{
    if (is_admin()) {
$plugin_path = dirname(plugin_basename(__FILE__)).'/lang';
load_plugin_textdomain('WPSupersized',false,$plugin_path);
    }
}

/**
* Tests if any of a post's assigned categories are descendants of target categories
*
* @param int|array $cats The target categories. Integer ID or array of integer IDs
* @param int|object $_post The post. Omit to test the current post in the Loop or main query
* @return bool True if at least 1 of the post's categories is a descendant of any of the target
categories
* @see get_term_by() You can get a category by name or slug, then pass ID to this function
* @uses get_term_children() Passes $cats
* @uses in_category() Passes $_post (can be empty)
* @version 2.7
*/
public static function post_is_in_descendant_category( $cats, $_post = null )
{
    foreach ( (array) $cats as $cat ) {
        // get_term_children() accepts integer ID only
        $descendants = get_term_children( (int) $cat, 'category' );
        if ( $descendants && in_category( $descendants, $_post ) )
        return true;
    }
    return false;
}

}
endif;


/**
* class WPSupersized_Test
*
* Basic version testing (at installation).
*/
if ( !class_exists('WPSupersized_Test') ):
class WPSupersized_Test
{
   /**
   * min_php_version
   *
   * Test that your PHP version is at least that of the $min_php_version.
   * @param $min_php_version   string   representing the minimum required version of PHP, e.g. '5.3.2'
   * @param $plugin_name    string   Name of the plugin for messaging purposes.
   * @return none      Exit with messaging if PHP version is too old.
   */
   static function min_php_version($min_php_version, $plugin_name) {
   
      $exit_msg = "The $plugin_name plugin requires PHP $min_php_version or newer. Contact your system administrator about updating your version of PHP";
         
      if (version_compare( phpversion(),$min_php_version,'<'))
      {
          exit ($exit_msg);
      }
   }
    /**
	* Checks that the current version of WordPress is current enough.
	*
	* @return none exit on fail.
	*/
   static function min_wordpress_version($min_wordpress_version, $plugin_name) {
		global $wp_version;
		$exit_msg = __("The $plugin_name plugin requires WordPress $min_wordpress_version or newer.
<a href='http://codex.wordpress.org/Upgrading_WordPress'>Please update!</a>");
         
      if (version_compare($wp_version,$min_wordpress_version,'<'))
      {
          exit ($exit_msg);
      }
   }
}
endif;
/* EOF */